// Copyright (c) 2018 Dominic Masters
//
// MIT License
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import React from 'react';
import { connect } from 'react-redux';
import { withLanguage } from '@public/language/Language';

import Page, { PageBoundary } from '@components/page/Page';
import BodySection from '@sections/body/BodySection';
import ClearSection from '@sections/layout/ClearSection';

import { Title } from '@objects/typography/Typography';

import Styles from './PrivacyPolicyPage.scss';

export default withLanguage(props => {
  let { lang } = props;
  return (
    <Page
      style="privacy-policy"
      className="p-privacy-policy"
      title={ lang.pages.privacy.title }
      background={ require('@assets/images/patterns/schoolbell.svg') }
    >
      <ClearSection />
      <PageBoundary small>
        <BodySection>
          <Title>{ lang.pages.privacy.heading }</Title>
          { lang.pages.privacy.policy }
        </BodySection>
      </PageBoundary>
      <ClearSection />
    </Page>
  );
});
